@@ -227,7 +227,7 @@ get_logo_path(void)
 
     cache_dir = get_cache_directory();
     logo_path = g_strconcat(cache_dir, G_DIR_SEPARATOR_S,
-                            "weather_logo.gif", NULL);
+                            "weather_logo.svg", NULL);
     g_free(cache_dir);
     return logo_path;
 }
@@ -242,6 +242,7 @@ logo_fetched(SoupSession *session,
         gchar *path = get_logo_path();
         GError *error = NULL;
         GdkPixbuf *pixbuf = NULL;
+        gint scale_factor;
         if (!g_file_set_contents(path, msg->response_body->data,
                                  msg->response_body->length, &error)) {
             g_warning(_("Error downloading met.no logo image to %s, "
@@ -251,10 +252,13 @@ logo_fetched(SoupSession *session,
             g_free(path);
             return;
         }
-        pixbuf = gdk_pixbuf_new_from_file(path, NULL);
+        scale_factor = gtk_widget_get_scale_factor(user_data);
+        pixbuf = gdk_pixbuf_new_from_file_at_size(path, 180 * scale_factor, -1, NULL);
         g_free(path);
         if (pixbuf) {
-            gtk_image_set_from_pixbuf(GTK_IMAGE(user_data), pixbuf);
+            cairo_surface_t *surface = gdk_cairo_surface_create_from_pixbuf(pixbuf, scale_factor, NULL);
+            gtk_image_set_from_surface(GTK_IMAGE(user_data), surface);
+            cairo_surface_destroy(surface);
             g_object_unref(pixbuf);
         }
     }
@@ -267,15 +271,18 @@ weather_summary_get_logo(plugin_data *data)
     GtkWidget *image = gtk_image_new();
     GdkPixbuf *pixbuf;
     gchar *path = get_logo_path();
+    gint scale_factor = gtk_widget_get_scale_factor(GTK_WIDGET(data->plugin));
 
-    pixbuf = gdk_pixbuf_new_from_file(path, NULL);
+    pixbuf = gdk_pixbuf_new_from_file_at_size(path, 180 * scale_factor, -1, NULL);
     g_free(path);
     if (pixbuf == NULL)
         weather_http_queue_request(data->session,
                                    "https://www.met.no/_/asset/no.met.metno:1497355518/images/met-logo.svg",
                                    logo_fetched, image);
     else {
-        gtk_image_set_from_pixbuf(GTK_IMAGE(image), pixbuf);
+        cairo_surface_t *surface = gdk_cairo_surface_create_from_pixbuf(pixbuf, scale_factor, NULL);
+        gtk_image_set_from_surface(GTK_IMAGE(image), surface);
+        cairo_surface_destroy(surface);
         g_object_unref(pixbuf);
     }
     return image;
@@ -861,9 +868,10 @@ add_forecast_cell(plugin_data *data,
                   gint time_of_day)
 {
     GtkWidget *box, *label, *image;
-    GdkPixbuf *icon;
+    cairo_surface_t *icon;
     gchar *wind_speed, *wind_direction, *value, *rawvalue;
     xml_time *fcdata;
+    gint scale_factor;
 
     box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
@@ -879,12 +887,13 @@ add_forecast_cell(plugin_data *data,
     /* symbol */
     rawvalue = get_data(fcdata, data->units, SYMBOL,
                         FALSE, data->night_time);
-    icon = get_icon(data->icon_theme, rawvalue, 48, (time_of_day == NIGHT));
+    scale_factor = gtk_widget_get_scale_factor(GTK_WIDGET(data->plugin));
+    icon = get_icon(data->icon_theme, rawvalue, 48, scale_factor, (time_of_day == NIGHT));
     g_free(rawvalue);
-    image = gtk_image_new_from_pixbuf(icon);
+    image = gtk_image_new_from_surface(icon);
     gtk_box_pack_start(GTK_BOX(box), GTK_WIDGET(image), TRUE, TRUE, 0);
     if (G_LIKELY(icon))
-        g_object_unref(G_OBJECT(icon));
+        cairo_surface_destroy(icon);
 
     /* symbol description */
     rawvalue = get_data(fcdata, data->units, SYMBOL,
@@ -1044,7 +1053,8 @@ create_forecast_tab(plugin_data *data)
     monitor = gdk_display_get_monitor_at_window(gdk_display_get_default(), window);
     if (G_LIKELY(window && monitor)) {
         gdk_monitor_get_geometry (monitor, &rect);
-    }
+    } else
+        return NULL;
 
     /* calculate maximum width and height */
     h_max = rect.height - 250;
@@ -1145,7 +1155,7 @@ update_summary_subtitle(plugin_data *data)
         return FALSE;
 
     time(&now_t);
-    date = format_date(now_t, "%A %_d %b %Y, %H:%M (%Z)", TRUE);
+    date = format_date(now_t, "%A %d %b %Y, %H:%M (%Z)", TRUE);
     title = g_markup_printf_escaped("<big><b>%s</b>\n%s</big>", data->location_name, date);
     g_free(date);
     gtk_label_set_markup(GTK_LABEL(data->summary_subtitle), title);
@@ -1159,21 +1169,32 @@ update_summary_subtitle(plugin_data *data)
     return FALSE;
 }
 
+static void
+open_config_dialog (GtkButton *button, plugin_data *data)
+{
+    GtkWidget *parent_window;
+
+    parent_window = gtk_widget_get_toplevel (GTK_WIDGET (button));
+    gtk_window_close (GTK_WINDOW (parent_window));
+    g_signal_emit_by_name (data->plugin, "configure-plugin", data, G_TYPE_NONE);
+}
+
 
 GtkWidget *
 create_summary_window(plugin_data *data)
 {
-    GtkWidget *window, *notebook, *vbox, *hbox, *label, *image;
-    GdkPixbuf *icon;
+    GtkWidget *window, *notebook, *vbox, *hbox, *label, *image, *button, *box;
+    cairo_surface_t *icon;
     xml_time *conditions;
     gchar *title, *symbol;
+    gint scale_factor;
 
     conditions = get_current_conditions(data->weatherdata);
-    window = xfce_titled_dialog_new_with_buttons(_("Weather Report"),
-                                                 NULL,
-                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                 _("Close"),
-                                                 GTK_RESPONSE_ACCEPT, NULL);
+    window = xfce_titled_dialog_new_with_mixed_buttons(_("Weather Report"),
+                                                       NULL,
+                                                       GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                       "window-close-symbolic", _("_Close"),
+                                                       GTK_RESPONSE_ACCEPT, NULL);
 
     data->summary_subtitle = gtk_label_new (NULL);
     if (G_LIKELY(data->location_name != NULL)) {
@@ -1185,34 +1206,60 @@ create_summary_window(plugin_data *data)
     gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area (GTK_DIALOG(window))), vbox, TRUE, TRUE, 0);
 
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
-    gtk_box_pack_start(GTK_BOX (vbox), hbox, TRUE, FALSE, 6);
+    gtk_box_pack_start(GTK_BOX (vbox), hbox, FALSE, FALSE, 6);
     image = gtk_image_new ();
     gtk_box_pack_start(GTK_BOX (hbox), image, FALSE, FALSE, 6);
     gtk_box_pack_start(GTK_BOX (hbox), data->summary_subtitle, FALSE, FALSE, 6);
 
     symbol = get_data(conditions, data->units, SYMBOL,
                       FALSE, data->night_time);
-    icon = get_icon(data->icon_theme, symbol, 48, data->night_time);
-    gtk_image_set_from_pixbuf (GTK_IMAGE (image), icon);
+    scale_factor = gtk_widget_get_scale_factor(GTK_WIDGET(data->plugin));
+    icon = get_icon(data->icon_theme, symbol, 48, scale_factor, data->night_time);
+    gtk_image_set_from_surface(GTK_IMAGE(image), icon);
     g_free(symbol);
 
-    gtk_window_set_icon_name(GTK_WINDOW(window), "xfce4-weather");
+    gtk_window_set_icon_name(GTK_WINDOW(window), "org.xfce.panel.weather");
 
     if (G_LIKELY(icon))
-        g_object_unref(G_OBJECT(icon));
+        cairo_surface_destroy(icon);
 
     if (data->location_name == NULL || data->weatherdata == NULL ||
         data->weatherdata->current_conditions == NULL) {
-        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+        box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+        gtk_widget_set_valign (box, GTK_ALIGN_CENTER);
+
+        gtk_widget_destroy (image);
+        icon = get_icon (data->icon_theme, NULL, 128, scale_factor, data->night_time);
+        image = gtk_image_new ();
+        gtk_image_set_from_surface (GTK_IMAGE (image), icon);
+        if (G_LIKELY (icon))
+            cairo_surface_destroy (icon);
+
+        gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (image),
+                            FALSE, FALSE, 6);
+
+        label = gtk_label_new (NULL);
+        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
+        gtk_widget_set_sensitive (label, FALSE);
+
         if (data->location_name == NULL)
-            label = gtk_label_new(_("Please set a location in the plugin settings."));
+            title = g_markup_printf_escaped("<big><b>%s</b></big>\n%s", _("No location selected."), _("Please set a location in the plugin settings."));
         else
-            label = gtk_label_new(_("Currently no data available."));
-        gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(label),
-                           TRUE, TRUE, 0);
+            title = g_markup_printf_escaped("<big><b>%s</b></big>", _("Currently no data available."));
+
+        gtk_label_set_markup (GTK_LABEL (label), title);
+        g_free (title);
+        gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (label),
+                            FALSE, FALSE, 6);
+
+        button = gtk_button_new_with_label (_("Plugin settings..."));
+        gtk_widget_set_halign (button, GTK_ALIGN_CENTER);
+        g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (open_config_dialog), data);
+        gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 6);
+
+        gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET(box),
+                            TRUE, TRUE, 0);
 
-        gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(hbox),
-                           TRUE, TRUE, 0);
         gtk_window_set_default_size(GTK_WINDOW(window), 500, 400);
     } else {
         notebook = gtk_notebook_new();
